@@ -224,8 +224,7 @@ enum {
   SPVM_OPCODE_C_ID_NEGATE_LONG,
   SPVM_OPCODE_C_ID_NEGATE_FLOAT,
   SPVM_OPCODE_C_ID_NEGATE_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_BYTE,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_SHORT,
+  SPVM_OPCODE_C_ID_GET_CONSTANT_CHAR,
   SPVM_OPCODE_C_ID_GET_CONSTANT_INT,
   SPVM_OPCODE_C_ID_GET_CONSTANT_LONG,
   SPVM_OPCODE_C_ID_GET_CONSTANT_FLOAT,
@@ -332,6 +331,7 @@ enum {
   SPVM_OPCODE_C_ID_IF_NE_ZERO,
   SPVM_OPCODE_C_ID_IF_CROAK_CATCH,
   SPVM_OPCODE_C_ID_IF_CROAK_RETURN,
+  SPVM_OPCODE_C_ID_TABLE_SWITCH,
   SPVM_OPCODE_C_ID_LOOKUP_SWITCH,
   SPVM_OPCODE_C_ID_ARRAY_FETCH_BYTE,
   SPVM_OPCODE_C_ID_ARRAY_FETCH_SHORT,
