@@ -224,8 +224,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "NEGATE_LONG",
   "NEGATE_FLOAT",
   "NEGATE_DOUBLE",
-  "GET_CONSTANT_BYTE",
-  "GET_CONSTANT_SHORT",
+  "GET_CONSTANT_CHAR",
   "GET_CONSTANT_INT",
   "GET_CONSTANT_LONG",
   "GET_CONSTANT_FLOAT",
@@ -332,6 +331,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "IF_NE_ZERO",
   "IF_CROAK_CATCH",
   "IF_CROAK_RETURN",
+  "TABLE_SWITCH",
   "LOOKUP_SWITCH",
   "ARRAY_FETCH_BYTE",
   "ARRAY_FETCH_SHORT",
