@@ -8,6 +8,7 @@
 #include "spvm_type.h"
 #include "spvm_limit.h"
 #include "spvm_hash.h"
+#include "spvm_constant_pool.h"
 
 const char* const SPVM_PACKAGE_C_CATEGORY_NAMES[] = {
   "class",
@@ -39,15 +40,15 @@ SPVM_PACKAGE* SPVM_PACKAGE_new(SPVM_COMPILER* compiler) {
   package->info_sub_id_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
   package->info_field_ids = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
   package->info_field_id_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
-  package->info_types = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
-  package->info_type_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  package->info_basic_type_ids = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
+  package->info_basic_type_id_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
   package->info_switch_infos = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
-  package->info_long_constants = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
-  package->info_long_constant_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
-  package->info_double_constants = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
-  package->info_double_constant_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
-  package->info_string_constants = SPVM_COMPILER_ALLOCATOR_alloc_list(compiler, 0);
-  package->info_string_constant_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  package->string_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  
+  package->constant_pool = SPVM_COMPILER_ALLOCATOR_alloc_constant_pool(compiler, 0);
+  
+  package->constant_pool_32bit_value_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  package->constant_pool_64bit_value_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
   
   return package;
 }
