@@ -16,14 +16,14 @@ Construct Long object with specified value.
 
 =head1 METHODS
 
-=head2 get_value
+=head2 val
 
-  sub get_value : long ($self : self)
+  sub val : long ($self : self)
 
 Get value.
 
-=head2 set_value
+=head2 set_val
 
-  sub set_value : void ($self : self, $value : long)
+  sub set_val : void ($self : self, $value : long)
 
 Set value.
